@@ -3,14 +3,13 @@ package Mail::MtPolicyd::Plugin::Accounting;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for accounting in sql tables
 
 extends 'Mail::MtPolicyd::Plugin';
 with 'Mail::MtPolicyd::Plugin::Role::UserConfig' => {
 	'uc_attributes' => [ 'enabled' ],
 };
-with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
 
 use Mail::MtPolicyd::Plugin::Result;
 
@@ -29,6 +28,12 @@ has '_fields' => ( is => 'ro', isa => 'ArrayRef', lazy => 1,
 
 has 'time_pattern' => ( is => 'rw', isa => 'Str', default => '%Y-%m');
 
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'db',
+  type => 'Sql',
+};
+with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
+
 sub get_timekey {
     my $self = shift;
     return Time::Piece->new->strftime( $self->time_pattern );
@@ -145,7 +150,7 @@ sub update_accounting {
 
 sub insert_accounting_row {
     my ( $self, $field, $key, $metrics ) = @_;
-    my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+    my $dbh = $self->_db_handle;
     my $table_name = $dbh->quote_identifier( $self->get_table_name($field) );
     my $values = {
         'key' => $key,
@@ -167,7 +172,7 @@ sub insert_accounting_row {
 
 sub update_accounting_row {
     my ( $self, $field, $key, $metrics ) = @_;
-    my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+    my $dbh = $self->_db_handle;
     my $table_name = $dbh->quote_identifier( $self->get_table_name($field) );
     my $where = {
         'key' => $key,
@@ -207,7 +212,7 @@ Mail::MtPolicyd::Plugin::Accounting - mtpolicyd plugin for accounting in sql tab
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 SYNOPSIS
 
