@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::DBL;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for checking helo,sender domain,rdns against an DBL
 
 extends 'Mail::MtPolicyd::Plugin';
@@ -64,7 +64,8 @@ sub run {
 			next;
 		}
 
-		$self->log($r, 'domain '.$hostname.' is on '.$self->domain.' blacklist ('.$info.')');
+    $self->log($r, 'domain '.$hostname.' is on '.$self->domain.' blacklist'.
+      ( defined $info ? " ($info)" : '' ) );
 
 		my $score_attr = $check.'_score';
 		if( defined $self->$score_attr &&
@@ -143,7 +144,7 @@ Mail::MtPolicyd::Plugin::DBL - mtpolicyd plugin for checking helo,sender domain,
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 DESCRIPTION
 
