@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::GeoIPAction;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for checking geo information of an ip
 
 
@@ -59,6 +59,9 @@ sub run {
 		return;
 	}
 	my ( $country_code ) = @{$session->{$result_key}};
+  if( ! defined $country_code ) {
+    return;
+  }
 
 	if( ! $self->is_in_country_codes( $country_code ) ) {
 		$self->log( $r, 'country_code '.$country_code.' of IP not in country_code list'.$self->name);
@@ -107,7 +110,7 @@ Mail::MtPolicyd::Plugin::GeoIPAction - mtpolicyd plugin for checking geo informa
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 DESCRIPTION
 
