@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::Greylist;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: This plugin implements a greylisting mechanism with an auto whitelist.
 
 extends 'Mail::MtPolicyd::Plugin';
@@ -11,7 +11,6 @@ with 'Mail::MtPolicyd::Plugin::Role::Scoring';
 with 'Mail::MtPolicyd::Plugin::Role::UserConfig' => {
 	'uc_attributes' => [ 'enabled' ],
 };
-with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
 
 use Mail::MtPolicyd::Plugin::Result;
 use Time::Piece;
@@ -38,6 +37,17 @@ has 'autowl_table' => ( is => 'rw', isa => 'Str', default => 'autowl' );
 has 'query_autowl' => ( is => 'rw', isa => 'Bool', default => 1 );
 has 'create_ticket' => ( is => 'rw', isa => 'Bool', default => 1 );
 
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'db',
+  type => 'Sql',
+};
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'memcached',
+  type => 'Memcached',
+};
+
+with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
+
 sub run {
 	my ( $self, $r ) = @_;
 	my $ip = $r->attr('client_address');
@@ -220,7 +230,7 @@ sub expire_autowl_rows {
 sub get_ticket {
 	my ( $self, $r, $sender, $ip, $rcpt ) = @_;
 	my $key = join(",", $sender, $ip, $rcpt );
-	if( my $ticket = $r->server->memcached->get( $key ) ) {
+	if( my $ticket = $self->_memcached_handle->get( $key ) ) {
 		return( $ticket );
 	}
 	return;
@@ -237,7 +247,7 @@ sub is_valid_ticket {
 sub remove_ticket {
 	my ( $self, $r, $sender, $ip, $rcpt ) = @_;
 	my $key = join(",", $sender, $ip, $rcpt );
-	$r->server->memcached->delete( $key );
+	$self->_memcached_handle->delete( $key );
 	return;
 }
 
@@ -245,7 +255,7 @@ sub do_create_ticket {
 	my ( $self, $r, $sender, $ip, $rcpt ) = @_;
 	my $ticket = time + $self->min_retry_wait;
 	my $key = join(",", $sender, $ip, $rcpt );
-	$r->server->memcached->set( $key, $ticket, $self->max_retry_wait );
+	$self->_memcached_handle->set( $key, $ticket, $self->max_retry_wait );
 	return;
 }
 
@@ -309,7 +319,7 @@ Mail::MtPolicyd::Plugin::Greylist - This plugin implements a greylisting mechani
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 DESCRIPTION
 
