@@ -3,25 +3,16 @@ package Mail::MtPolicyd::Plugin::LdapUserConfig;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for retrieving per user configuration from LDAP
 
 extends 'Mail::MtPolicyd::Plugin';
 
 
-use Mail::MtPolicyd::LdapConnection;
 use Mail::MtPolicyd::Plugin::Result;
 
 use Net::LDAP::Util qw( escape_filter_value );
 
-sub init {
-  my $self = shift;
-  if( ! Mail::MtPolicyd::LdapConnection->is_initialized ) {
-    die('no ldap connection initialized, but required for plugin '.$self->name);
-  }
-  return;
-};
-
 has 'basedn' => ( is => 'rw', isa => 'Str', default => '' );
 
 has 'filter' => ( is => 'rw', isa => 'Str', required => 1 );
@@ -47,9 +38,17 @@ has '_config_fields' => (
   },
 );
 
+has 'connection' => ( is => 'ro', isa => 'Str', default => 'ldap' );
+has 'connection_type' => ( is => 'ro', isa => 'Str', default => 'Ldap' );
+
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'ldap',
+  type => 'Ldap',
+};
+
 sub retrieve_ldap_entry {
   my ( $self, $r ) = @_;
-  my $ldap = Mail::MtPolicyd::LdapConnection->handle;
+  my $ldap = $self->_ldap_handle;
 
   my $value = $self->get_filter_value( $r );
   if( ! defined $value ) {
@@ -118,7 +117,7 @@ Mail::MtPolicyd::Plugin::LdapUserConfig - mtpolicyd plugin for retrieving per us
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 SYNOPSIS
 
