@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::Quota;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for accounting in sql tables
 
 extends 'Mail::MtPolicyd::Plugin';
@@ -12,7 +12,6 @@ with 'Mail::MtPolicyd::Plugin::Role::UserConfig' => {
         'enabled', 'field', 'threshold', 'action', 'metric'
     ],
 };
-with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
 with 'Mail::MtPolicyd::Plugin::Role::PluginChain';
 
 use Mail::MtPolicyd::Plugin::Result;
@@ -27,6 +26,12 @@ has 'time_pattern' => ( is => 'rw', isa => 'Str', default => '%Y-%m');
 has 'threshold' => ( is => 'rw', isa => 'Int', required => 1);
 has 'action' => ( is => 'rw', isa => 'Str', default => 'defer smtp traffic quota has been exceeded');
 
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'db',
+  type => 'Sql',
+};
+with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
+
 sub get_timekey {
     my $self = shift;
     return Time::Piece->new->strftime( $self->time_pattern );
@@ -79,7 +84,7 @@ sub get_table_name {
 
 sub get_accounting_count {
     my ( $self, $r, $field, $metric, $key ) = @_;
-    my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+    my $dbh = $self->_db_handle;
     my $where = {
         'key' => $key,
         'time' => $self->get_timekey,
@@ -115,7 +120,7 @@ Mail::MtPolicyd::Plugin::Quota - mtpolicyd plugin for accounting in sql tables
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 DESCRIPTION
 
