@@ -3,22 +3,14 @@ package Mail::MtPolicyd::Plugin::Role::SqlUtils;
 use strict;
 use Moose::Role;
 
-use Mail::MtPolicyd::SqlConnection;
-
 # ABSTRACT: role with support function for plugins using sql
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 
-before 'init' => sub {
-    my $self = shift;
-    if( ! Mail::MtPolicyd::SqlConnection->is_initialized ) {
-        die('no sql database initialized, but required for plugin '.$self->name);
-    }
-    return;
-};
+requires '_db_handle';
 
 sub sql_table_exists {
     my ( $self, $name ) = @_;
-	my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+  my $dbh = $self->_db_handle;
     my $sql = 'SELECT * FROM '.$dbh->quote_identifier($name).' WHERE 1=0;';
     eval { $dbh->do($sql); };
     if( $@ ) {
@@ -29,7 +21,7 @@ sub sql_table_exists {
 
 sub create_sql_table {
     my ( $self, $name, $definitions ) = @_;
-	my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+  my $dbh = $self->_db_handle;
     my $table_name = $dbh->quote_identifier($name);
     my $sql;
     my $driver = $dbh->{Driver}->{Name};
@@ -61,7 +53,7 @@ sub check_sql_tables {
 
 sub execute_sql {
     my ( $self, $sql, @params ) = @_;
-	my $dbh = Mail::MtPolicyd::SqlConnection->instance->dbh;
+  my $dbh = $self->_db_handle;
     my $sth = $dbh->prepare( $sql );
     $sth->execute( @params );
     return $sth;
@@ -81,7 +73,7 @@ Mail::MtPolicyd::Plugin::Role::SqlUtils - role with support function for plugins
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 AUTHOR
 
