@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::SqlList;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for accessing a SQL white/black/access list
 
 extends 'Mail::MtPolicyd::Plugin';
@@ -11,7 +11,6 @@ with 'Mail::MtPolicyd::Plugin::Role::Scoring';
 with 'Mail::MtPolicyd::Plugin::Role::UserConfig' => {
 	'uc_attributes' => [ 'enabled' ],
 };
-with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
 
 use Mail::MtPolicyd::Plugin::Result;
 
@@ -27,6 +26,12 @@ has 'score' => ( is => 'rw', isa => 'Maybe[Num]' );
 has 'match_action' => ( is => 'rw', isa => 'Maybe[Str]' );
 has 'not_match_action' => ( is => 'rw', isa => 'Maybe[Str]' );
 
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'db',
+  type => 'Sql',
+};
+with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
+
 sub _query_db {
 	my ( $self, $ip ) = @_;
 	return $self->execute_sql($self->sql_query, $ip)->fetchrow_array;
@@ -91,7 +96,7 @@ Mail::MtPolicyd::Plugin::SqlList - mtpolicyd plugin for accessing a SQL white/bl
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 SYNOPSIS
 
