@@ -3,11 +3,10 @@ package Mail::MtPolicyd::Plugin::SqlUserConfig;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '2.00'; # VERSION
 # ABSTRACT: mtpolicyd plugin for retrieving the user config of a user
 
 extends 'Mail::MtPolicyd::Plugin';
-with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
 
 
 use Mail::MtPolicyd::Plugin::Result;
@@ -27,6 +26,12 @@ has '_json' => (
 
 has 'field' => ( is => 'rw', isa => 'Str', default => 'recipient' );
 
+with 'Mail::MtPolicyd::Role::Connection' => {
+  name => 'db',
+  type => 'Sql',
+};
+with 'Mail::MtPolicyd::Plugin::Role::SqlUtils';
+
 sub _get_config {
 	my ( $self, $r ) = @_;
 	my $key = $r->attr( $self->field );
@@ -76,7 +81,7 @@ Mail::MtPolicyd::Plugin::SqlUserConfig - mtpolicyd plugin for retrieving the use
 
 =head1 VERSION
 
-version 1.23
+version 2.00
 
 =head1 DESCRIPTION
 
